OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "פרטי המעבד לא זמינים",
    "Not supported!" : "אין תמיכה!",
    "Press ⌘-C to copy." : "להעתקה: ‎⌘-C.",
    "Press Ctrl-C to copy." : "להעתקה: Ctrl-C.",
    "System" : "מערכת",
    "Monitoring" : "מעקב",
    "Monitoring app with useful server information" : "יישום מעקב עם פרטים חשובים על השרת",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "מספק פרטים חיוניים על השרת כגון העומס על המעבד, ניצולת הזיכרון, ניצולת נפח הכונן מספר המשתמשים וכו׳",
    "Temperature" : "טמפרטורה",
    "Load" : "עומס",
    "Memory" : "זיכרון",
    "Disk" : "כונן",
    "Size:" : "גודל:",
    "You will get a notification once one of your disks is nearly full." : "תישלח אליך התראה כשהכונן עומד להתמלא לחלוטין.",
    "Files:" : "קבצים",
    "Storages:" : "אמצעי אחסון:",
    "Free Space:" : "מקום פנוי:",
    "Network" : "רשת",
    "Active users" : "משתמשים פעילים",
    "Total users:" : "סך כל המשתמשים:",
    "Shares" : "שיתופים",
    "Users:" : "משתמשים:",
    "PHP" : "PHP",
    "Version:" : "גרסה:",
    "Upload max size:" : "גודל העלאה מרבי:",
    "Database" : "מסד נתונים",
    "Type:" : "סוג:",
    "External monitoring tool" : "כלי מעקב חיצוני",
    "You can connect an external monitoring tool by using this end point:" : "ניתן לחבר לכלי מעקב חיצוני דרך נקודת הגישה הזאת:",
    "Copy" : "העתקה",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "הוספת „‎?format=json” לסוף הכתובת יעניק לך את התוצאה ב־JSON.",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "לאחר מכן יש להעביר את האסימון עם כותרת „NC-Token” בעת תשאול הכתובת שלעיל.",
    "Users" : "משתמשים",
    "Groups" : "קבוצות",
    "Links" : "קישורים",
    "Emails" : "כתובות דוא״ל",
    "Federated sent" : "בקשת איגוד נשלחה",
    "Federated received" : "בקשת איגוד התקבלה",
    "Talk conversations" : "דיוני שיח",
    "24 hours" : "24 שעות",
    "1 hour" : "שעה",
    "5 mins" : "5 דקות",
    "Copied!" : "הועתק!",
    "Operating System" : "מערכת הפעלה",
    "CPU" : "מעבד",
    "Server time" : "זמן השרת",
    "Uptime" : "זמן פעילות",
    "Mount" : "עגינה",
    "Filesystem" : "מערכת קבצים",
    "Size" : "גודל",
    "Available" : "זמינות",
    "Used" : "מנוצלים",
    "Files" : "קבצים",
    "Hostname" : "שם מארח",
    "DNS" : "DNS",
    "Gateway" : "שער גישה",
    "Status" : "מצב",
    "Speed" : "מהירות",
    "MAC" : "כתובת חומרה",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Version" : "גרסה",
    "Type" : "סוג"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
